IfNode class

@if/@elseif/@else/@endif.

Inheritance

Constructors

IfNode(int line, List<IfBranch> branches, List<Node>? elseBody)
const

Properties

branches List<IfBranch>
final
elseBody List<Node>?
final
hashCode int
The hash code for this object.
no setterinherited
line int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited