IncludeNode class

@include('view') / @include('view', {data}).

Inheritance

Constructors

IncludeNode(int line, Expression view, Expression? data)
const

Properties

data Expression?
final
hashCode int
The hash code for this object.
no setterinherited
line int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view Expression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited