TemplateLoader class abstract

Where templates come from. Implement to load from a database, assets bundled in a binary, and so on.

Constructors

TemplateLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(String name) TemplateSource?
Returns null when no template has this name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited